/*
Copyright 2000-2019 Vadim Druzhin <cdslow@mail.ru>

You can redistribute and/or modify this file under the terms
of the GNU General Public License version 3 or any later version.

See file COPYING.txt or visit <http://www.gnu.org/licenses/>.
*/

#define STRICT
#include <windows.h>
#include "log.h"
#include "build.h"
#include "cdslow.h"

int WINAPI WinMain(
    HINSTANCE hInstance, HINSTANCE hPrevInstance,
    LPSTR lpszCmdLine, int nCmdShow)
    {
    HWND window;
    BOOL restart=FALSE;
    BOOL hide=FALSE;

    (void)hPrevInstance; /* Unused */
    (void)nCmdShow; /* Unused */

    if(0==strncmp(lpszCmdLine, "/log", 4))
        {
        InitLog(NULL, NULL);
        lpszCmdLine+=4;
        while(' '==*lpszCmdLine)
            ++lpszCmdLine;
        }

    if(IsAutoExitStr(lpszCmdLine))
        {
        DebugLog(("Setting speed and exiting...\n"));
        CDSlowOnce();
        return 0;
        }

    if(IsHideStr(lpszCmdLine))
        hide=TRUE;

    if(IsRestartStr(lpszCmdLine))
        restart=TRUE;

    window=FindWindow(AppName, AppName);
    if(window!=NULL)
        {
        DebugLog(("Another instance of %s found\n", AppName));
        if(hide)
            {
            DebugLog(("Sending HIDE to 0x%x\n", window));
            HideIcon(window);
            return 0;
            }
        else if(restart)
            {
            DebugLog(("Sending CLOSE to 0x%x\n", window));
            SendMessage(window, WM_CLOSE, 0, 0);
            }
        else
            {
            DebugLog(("Sending SHOW to 0x%x\n", window));
            ShowIcon(window);
            return 0;
            }
        }
    else
        {
#ifdef BUILD_ID
        DebugLog(("First instance of %s%s started\n", AppName, BUILD_ID));
#else
        DebugLog(("First instance of %s started\n", AppName));
#endif
        }

    CDSlow(hInstance, hide);

    return 0;
    }
